@@ -30,7 +30,6 @@
 
 static QObject* temperatureUnitListModelSingletonTypeProvider(QQmlEngine *engine, QJSEngine *scriptEngine)
 {
-    Q_UNUSED(engine)
     Q_UNUSED(scriptEngine)
 
     QVector<UnitItem> items {
@@ -39,12 +38,11 @@ static QObject* temperatureUnitListModelSingletonTypeProvider(QQmlEngine *engine
         UnitItem(KUnitConversion::Kelvin)
     };
 
-    return new AbstractUnitListModel(items);
+    return new AbstractUnitListModel(items, engine);
 }
 
 static QObject* pressureUnitListModelSingletonTypeProvider(QQmlEngine *engine, QJSEngine *scriptEngine)
 {
-    Q_UNUSED(engine)
     Q_UNUSED(scriptEngine)
 
     QVector<UnitItem> items {
@@ -55,12 +53,11 @@ static QObject* pressureUnitListModelSingletonTypeProvider(QQmlEngine *engine, Q
         UnitItem(KUnitConversion::MillimetersOfMercury)
     };
 
-    return new AbstractUnitListModel(items);
+    return new AbstractUnitListModel(items, engine);
 }
 
 static QObject* windSpeedUnitListModelSingletonTypeProvider(QQmlEngine *engine, QJSEngine *scriptEngine)
 {
-    Q_UNUSED(engine)
     Q_UNUSED(scriptEngine)
 
     QVector<UnitItem> items {
@@ -71,12 +68,11 @@ static QObject* windSpeedUnitListModelSingletonTypeProvider(QQmlEngine *engine,
         UnitItem(KUnitConversion::Beaufort)
     };
 
-    return new AbstractUnitListModel(items);
+    return new AbstractUnitListModel(items, engine);
 }
 
 static QObject* visibilityUnitListModelSingletonTypeProvider(QQmlEngine *engine, QJSEngine *scriptEngine)
 {
-    Q_UNUSED(engine)
     Q_UNUSED(scriptEngine)
 
     QVector<UnitItem> items {
@@ -84,7 +80,7 @@ static QObject* visibilityUnitListModelSingletonTypeProvider(QQmlEngine *engine,
         UnitItem(KUnitConversion::Mile)
     };
 
-    return new AbstractUnitListModel(items);
+    return new AbstractUnitListModel(items, engine);
 }
 
 static QObject* utilSingletonTypeProvider(QQmlEngine *engine, QJSEngine *scriptEngine)
