@@ -26,8 +26,8 @@ class ComicPackage : public KPackage::PackageStructure
     Q_OBJECT
 
 public:
-        explicit ComicPackage(QObject *parent = 0, const QVariantList& args = QVariantList());
-        void initPackage(KPackage::Package *package) Q_DECL_OVERRIDE;
+        explicit ComicPackage(QObject *parent = nullptr, const QVariantList& args = QVariantList());
+        void initPackage(KPackage::Package *package) override;
 };
 
 #endif
