@@ -19,8 +19,8 @@
 #ifndef COMICPROVIDER_H
 #define COMICPROVIDER_H
 
-#include <QtCore/QDate>
-#include <QtCore/QObject>
+#include <QDate>
+#include <QObject>
 #include <KPluginInfo>
 #include <KPluginFactory>
 
@@ -64,7 +64,7 @@ class PLASMA_COMIC_EXPORT ComicProvider : public QObject
         /**
          * Destroys the comic provider.
          */
-        virtual ~ComicProvider();
+        ~ComicProvider() override;
 
         /**
          * Returns the type of identifier that is used by this
@@ -151,12 +151,12 @@ class PLASMA_COMIC_EXPORT ComicProvider : public QObject
         virtual QString name() const;
 
         /**
-         * Returns wether the comic is leftToRight or not
+         * Returns whether the comic is leftToRight or not
          */
         virtual bool isLeftToRight() const;
 
         /**
-        * Returns wether the comic is topToBottom or not
+        * Returns whether the comic is topToBottom or not
         */
         virtual bool isTopToBottom() const;
 
