@@ -1,11 +1,12 @@
 /*
- * Copyright (C) 2010, 2012 Jason A. Donenfeld <Jason@zx2c4.com>
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ * SPDX-FileCopyrightText: 2010, 2012 Jason A. Donenfeld <Jason@zx2c4.com>
  */
 
 #include "dictionaryrunner.h"
 
 #include <QStringList>
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
 static const char CONFIG_TRIGGERWORD[] = "triggerWord";
 
@@ -83,6 +84,6 @@ void DictionaryRunner::match(Plasma::RunnerContext &context)
     context.addMatches(matches);
 }
 
-K_EXPORT_PLASMA_RUNNER(krunner_dictionary, DictionaryRunner)
+K_EXPORT_PLASMA_RUNNER_WITH_JSON(DictionaryRunner, "plasma-runner-dictionary.json")
 
 #include "dictionaryrunner.moc"
